@@ -184,7 +184,7 @@ class CfPostgresql(CfDatabase):
 
         return all_fields_present
 
-    def get_primary_keys(self, table_path: str = None) -> List[psycopg2.extras.DictRow]:
+    def get_primary_keys(self, table_path: str = None) -> List[str]:
         """Get a table's primary key(s).
 
         Args:
